==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ResponsiveStateEnteringEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateEnteringEventArgsDescription } from "./ResponsiveStateEnteringEventArgsDescription";
/**
 * @hidden
 */
var ResponsiveStateEnteringEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ResponsiveStateEnteringEventArgsDescriptionMetadata, _super);
    function ResponsiveStateEnteringEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ResponsiveStateEnteringEventArgsDescriptionMetadata.b = function (a) {
        if (ResponsiveStateEnteringEventArgsDescriptionMetadata.a == null) {
            ResponsiveStateEnteringEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ResponsiveStateEnteringEventArgsDescriptionMetadata.c(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
        }
        if (a.j(ResponsiveStateEnteringEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.c = function (a) {
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.d = function (a) {
        ResponsiveStateEnteringEventArgsDescriptionMetadata.b(a);
        a.aa("ResponsiveStateEnteringEventArgs", function () { return new ResponsiveStateEnteringEventArgsDescription(); });
        a.z("ResponsiveStateEnteringEventArgs", ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.$t = markType(ResponsiveStateEnteringEventArgsDescriptionMetadata, 'ResponsiveStateEnteringEventArgsDescriptionMetadata');
    ResponsiveStateEnteringEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateEnteringEventArgsDescriptionMetadata;
}(Base));
export { ResponsiveStateEnteringEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ResponsiveStateEnteringEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateEnteringEventArgsDescription } from "./ResponsiveStateEnteringEventArgsDescription";
/**
 * @hidden
 */
var ResponsiveStateEnteringEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ResponsiveStateEnteringEventArgsDescriptionMetadata, _super);
    function ResponsiveStateEnteringEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ResponsiveStateEnteringEventArgsDescriptionMetadata.b = function (a) {
        if (ResponsiveStateEnteringEventArgsDescriptionMetadata.a == null) {
            ResponsiveStateEnteringEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ResponsiveStateEnteringEventArgsDescriptionMetadata.c(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
        }
        if (a.k(ResponsiveStateEnteringEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.c = function (a) {
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.d = function (a) {
        ResponsiveStateEnteringEventArgsDescriptionMetadata.b(a);
        a.ac("ResponsiveStateEnteringEventArgs", function () { return new ResponsiveStateEnteringEventArgsDescription(); });
        a.ab("ResponsiveStateEnteringEventArgs", ResponsiveStateEnteringEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateEnteringEventArgsDescriptionMetadata.$t = markType(ResponsiveStateEnteringEventArgsDescriptionMetadata, 'ResponsiveStateEnteringEventArgsDescriptionMetadata');
    ResponsiveStateEnteringEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateEnteringEventArgsDescriptionMetadata;
}(Base));
export { ResponsiveStateEnteringEventArgsDescriptionMetadata };
